# -*- coding: utf-8 -*-
#
# File: testSetup.py
#
# Copyright (c) 2007 by Jean Rodrigo Ferri
# Generator: ArchGenXML
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Jean Rodrigo Ferri <jeanrodrigoferri@yahoo.com.br>"""
__docformat__ = 'plaintext'

##code-section module-header #fill in your manual code here
##/code-section module-header

#
# Setup tests
#

import os, sys
from Testing import ZopeTestCase
from Products.windowZ.tests.windowZTestCase import windowZTestCase

class testSetup(windowZTestCase):
    """Test cases for the generic setup of the product."""

    ##code-section class-header_testSetup #fill in your manual code here
    ##/code-section class-header_testSetup

    def afterSetUp(self):
        ids = self.portal.objectIds()

    def test_tools(self):
        ids = self.portal.objectIds()
        self.failUnless('portal_windowz' in ids)

    def test_types(self):
        ids = self.portal.portal_types.objectIds()
        self.failUnless('Window' in ids)

    def test_skins(self):
        ids = self.portal.portal_skins.objectIds()
        self.failUnless('windowZ' in ids)

    def test_workflowChains(self):
        getChain = self.portal.portal_workflow.getChainForPortalType
        self.failUnless('simple_publication_workflow' in getChain('Window'))

    # Manually created methods


def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(testSetup))
    return suite

##code-section module-footer #fill in your manual code here
##/code-section module-footer




# -*- coding: utf-8 -*-
#
# File: WindowZTool.py
#
# Copyright (c) 2007 by Jean Rodrigo Ferri
# Generator: ArchGenXML
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Jean Rodrigo Ferri <jeanrodrigoferri@yahoo.com.br>"""
__docformat__ = 'plaintext'

from zope.interface import implements, classProvides
from zope.schema.fieldproperty import FieldProperty
from AccessControl import ClassSecurityInfo
from OFS.SimpleItem import SimpleItem
from App.class_init import InitializeClass

from Products.CMFCore.utils import UniqueObject

from Products.windowZ.interfaces import IWindowZTool, IWindowZSettings

class WindowZTool(UniqueObject, SimpleItem):
    """The windowZ tool. A singleton object that provides functionality
    to Window objects. The fixed id is portal_windowZ.
    """

    implements(IWindowZTool, IWindowZSettings)

    id = 'portal_windowz'
    title = 'windowZ Tool'
    meta_type= 'WindowZTool'
    plone_tool = True
    security = ClassSecurityInfo()

    page_width = FieldProperty(IWindowZSettings['page_width'])
    page_height = FieldProperty(IWindowZSettings['page_height'])
    base_url = FieldProperty(IWindowZSettings['base_url'])
    http_proxy = FieldProperty(IWindowZSettings['http_proxy'])
    dynamic_window = FieldProperty(IWindowZSettings['dynamic_window'])

    # BBB methods from old Archetype content tool
    def getPage_width(self):
        return self.page_width

    def getPage_height(self):
        return self.page_height

    def getBase_url(self):
        return self.base_url

    def getHttp_proxy(self):
        return self.http_proxy

    def getDynamic_window(self):
        return self.dynamic_window

    # setter
    def setPage_width(self, value):
        self.page_width = value

    def setPage_height(self, value):
        self.page_height = value

    def setBase_url(self, value):
        self.base_url = value

    def setHttp_proxy(self, value):
        self.http_proxy = value

    def setDynamic_window(self, value):
        self.dynamic_window = value

InitializeClass(WindowZTool)



# -*- coding: utf-8 -*-
#
# File: testClasses.py
#
# Copyright (c) 2007 by Jean Rodrigo Ferri
# Generator: ArchGenXML
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Jean Rodrigo Ferri <jeanrodrigoferri@yahoo.com.br>"""
__docformat__ = 'plaintext'

##code-section module-header #fill in your manual code here
##/code-section module-header

#
# Test-cases for class(es) Window, WindowZTool
#

from Testing import ZopeTestCase
from Products.windowZ.config import *
from Products.windowZ.tests.windowZTestCase import windowZTestCase

# Import the tested classes
from Products.windowZ.content.Window import Window
from Products.windowZ.WindowZTool import WindowZTool

##code-section module-beforeclass #fill in your manual code here
##/code-section module-beforeclass


class testClasses(windowZTestCase):
    """Test-cases for class(es) Window, WindowZTool."""

    ##code-section class-header_testClasses #fill in your manual code here
    ##/code-section class-header_testClasses

    def afterSetUp(self):
        self.folder.invokeFactory('Window', 'window')
        self.window = self.folder['window']

    # from class Window:
    def test_SearchableText(self):
        pass

    # from class Window:
    def test_view(self):
        pass

    # from class Window:
    def test_edit(self):
        pass

    # from class Window:
    def test_metadata(self):
        pass

    # from class Window:
    def test_local_roles(self):
        pass

    # Manually created methods

    def test_iframeurl(self):
        self.window.setRemoteUrl('http://www.plone.org/products')
        self.assertEqual(self.window.getUse_base_url(), False)
        self.assertEqual(self.window.remote_url(),
                         'http://www.plone.org/products')

    def test_iframeurl_with_base(self):
        self.portal.portal_windowz.setBase_url(u'ftp://')

        self.window.setRemoteUrl('www.plone.org/products')
        self.window.setUse_base_url(True)
        self.assertEqual(self.window.remote_url(),
                         'ftp://www.plone.org/products')

    def test_iframeurl_inherit_protocol(self):
        self.window.setRemoteUrl('http://www.plone.org/products')
        self.window.setInherit_protocol(True)
        self.assertEqual(self.window.getUse_base_url(), False)
        self.assertEqual(self.window.remote_url(),
                         'http://www.plone.org/products')

    def test_iframeurl_inherit_protocol(self):
        self.window.setRemoteUrl('http://www.plone.org/products')
        self.window.setInherit_protocol(True)
        self.app.REQUEST.set('SERVER_URL', 'https://nohost')
        self.assertEqual(self.window.getUse_base_url(), False)
        self.assertEqual(self.window.remote_url(),
                         'https://www.plone.org/products')

def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(testClasses))
    return suite

##code-section module-footer #fill in your manual code here
##/code-section module-footer





# -*- coding: utf-8 -*-
#
# File: testInterfaces.py
#
# Copyright (c) 2007 by Jean Rodrigo Ferri
# Generator: ArchGenXML
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Jean Rodrigo Ferri <jeanrodrigoferri@yahoo.com.br>"""
__docformat__ = 'plaintext'

#
# Interface tests
#

import unittest

from zope.interface.verify import verifyClass

from Products.windowZ.content.Window import Window
from Products.windowZ.interfaces import IWindow

class testInterfaces(unittest.TestCase):

    def testInterfacesForWindow(self):
        '''test interface compliance for class Window'''

        self.failUnless(verifyClass(IWindow, Window))

def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(testInterfaces))
    return suite




# -*- coding: utf-8 -*-
#
# File: Window.py
#
# Copyright (c) 2007 by Jean Rodrigo Ferri
# Generator: ArchGenXML
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Jean Rodrigo Ferri <jeanrodrigoferri@yahoo.com.br>"""
__docformat__ = 'plaintext'

import urlparse
import urllib2

from stripogram import html2text

import zope.interface
from AccessControl import ClassSecurityInfo

from Products.Archetypes.atapi import *
from Products.ATContentTypes.content.link import ATLink
from Products.ATContentTypes.content.link import ATLinkSchema

from Products.CMFCore.permissions import View
from Products.CMFCore.utils import getToolByName

from Products.windowZ.interfaces import IWindow
from Products.windowZ.config import PROJECTNAME
from Products.windowZ import WindowZMessageFactory as _

schema = Schema((

    StringField(
        name='page_width',
        widget=StringWidget(
            label=_('windowZ_label_page_width', default="Page Width"),
            description=_('windowZ_help_page_width', default=(
                "Enter a value for the page width. If it's not provided "
                "the page width will assumes the default value defined in "
                "the site setup. You may use %, px, em, etc.")),
            size=10,
        )
    ),

    StringField(
        name='page_height',
        widget=StringWidget(
            label=_('windowZ_label_page_height', default="Page Height"),
            description=_('windowZ_help_page_height', default=(
                "Enter a value for the page height. If it's not provided the "
                "page height will assumes the default value defined in the "
                "site setup. You may use %, px, em, etc.")),
            size=10,
        )
    ),

    BooleanField(
        name='hide_metadata',
        default=True,
        widget=BooleanWidget(
            label=_('windowZ_label_hide_metadata', default="Hide Metadata?"),
            description=_('windowZ_help_hide_metadata', default=(
                "Check this option if you want to hide the page metadata, "
                "like title, description, print and send page icons, author, "
                "etc.")),
        )
    ),

    BooleanField(
        name='use_base_url',
        widget=BooleanWidget(
            label=_('windowZ_label_use_base_url', default="Use Base URL?"),
            description=_('windowZ_help_use_base_url', default=(
                "Check this option if you want to use the base URL defined in "
                "the site setup as a prefix to the provided link.")),
        )
    ),

    BooleanField(
        name='catalog_page_content',
        default=True,
        widget=BooleanWidget(
            label=_('windowZ_label_catalog_page_content',
                    default="Catalog Page Content?"),
            description=_('windowZ_help_catalog_page_content', default=(
                "Check this option if you want to have the content of the "
                "provided page indexed in the site catalog and available "
                "in the portal search box.")),
        )
    ),

    BooleanField(
        name='show_reference',
        widget=BooleanWidget(
            label=_('windowZ_label_show_reference',
                    default="Show Reference?"),
            description=_('windowZ_help_show_reference', default=(
                "Check this option if you want to show the provided link as "
                "a reference in the bottom of the page.")),
        )
    ),

    BooleanField(
        name='inherit_protocol',
        widget=BooleanWidget(
            label=_('windowZ_label_inherit_protocol', "Inherit Protocol?"),
            description=_('windowZ_help_inherit_protocol', default=(
                "Check this option if you want to inherit the "
                "URL-protocol for the iframe from the content URL ")),
        )
    ),
),
)

##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

Window_schema = ATLinkSchema.copy() + \
    schema.copy()

##code-section after-schema #fill in your manual code here
Window_schema['remoteUrl'].accessor = 'getFrameUrl'
##/code-section after-schema

class Window(ATLink):
    """A Window is a content type that shows one URL inside an iFrame
    in a page of the site.
    """
    security = ClassSecurityInfo()
    zope.interface.implements(IWindow)

    meta_type = 'Window'
    _at_rename_after_creation = True

    schema = Window_schema

    security.declareProtected(View, 'SearchableText')
    def SearchableText(self):
        """Format the title, description and the provided page's content to
        be cataloged by portal_catalog, if user checked
        catalog_page_content option.
        """
        if self.getCatalog_page_content():
            try:
                self.getProxies() # open proxy connection
                remote_url = self.remote_url()
                page = urllib2.urlopen(remote_url)
                page_body = page.read()
            except:
                page_body = ''
            page_content = self._processPageBody(page_body)
        else:
            page_content = ''
        return "%s %s %s" % (self.Title(), self.Description(), page_content)

    # Methods from Interface IWindow

    security.declareProtected(View, 'getProxies')
    def getProxies(self):
        """Open proxy HTTP connection if it was setting on portal_windowz tool.
        """
        portal_windowz = getToolByName(self, 'portal_windowz')
        http_proxy = portal_windowz.getHttp_proxy()
        if http_proxy:
            try:
                proxies = {'http': http_proxy}
                proxy_support = urllib2.ProxyHandler(proxies)
                opener = urllib2.build_opener(proxy_support)
                urllib2.install_opener(opener)
            except:
                pass

    security.declareProtected(View, 'getPageHeight')
    def getPageHeight(self):
        """Returns page_height or the default value from portal_windowz.
        """
        if self.getPage_height():
            return self.getPage_height()
        else:
            portal_windowz = getToolByName(self, 'portal_windowz')
            if portal_windowz.getPage_height():
                return portal_windowz.getPage_height()
        return '500px'

    security.declareProtected(View, 'remote_url')
    def remote_url(self):
        """Returns the Window URL through getFrameUrl method prefixed with
        base_url if it's selected by user.
        """
        if self.getUse_base_url():
            portal_windowz = getToolByName(self, 'portal_windowz')
            base_url = portal_windowz.getBase_url()
            url = "%s%s" % (base_url, self.getFrameUrl())
        else:
            url = self.getFrameUrl()
        if self.getInherit_protocol():
            scheme = urlparse.urlsplit(self.REQUEST.get('SERVER_URL'))[0]
            parts = list(urlparse.urlsplit(url))
            parts[0] = scheme
            url = urlparse.urlunsplit(parts)
        return url

    security.declareProtected(View, 'getPageWidth')
    def getPageWidth(self):
        """Returns page_width or the default value from portal_windowz.
        """
        if self.getPage_width():
            return self.getPage_width()
        else:
            portal_windowz = getToolByName(self, 'portal_windowz')
            if portal_windowz.getPage_width():
                return portal_windowz.getPage_width()
        return '100%'

    security.declarePrivate('_processPageBody')
    def _processPageBody(self, page_body):
        """Process the link body with strip-o-gram library catching only the
        page content.
        """
        ignored_tags = ('img', 'style')
        page_content = html2text(page_body, ignore_tags=ignored_tags)
        return page_content


registerType(Window, PROJECTNAME)







from zope.interface import implements

from plone.fieldsets.fieldsets import FormFieldsets
from plone.app.controlpanel.form import ControlPanelForm

from Products.windowZ import WindowZMessageFactory as _
from Products.windowZ.interfaces import IWindowZControlPanelForm
from Products.windowZ.interfaces import IWindowZSettings

class WindowZControlPanelForm(ControlPanelForm):
    """WindowZ Control Panel Form"""

    implements(IWindowZControlPanelForm)

    windowzsettings = FormFieldsets(IWindowZSettings)
    windowzsettings.id = 'windowzsettings'
    windowzsettings.label = _(u'Settings')

    form_fields = FormFieldsets(windowzsettings)

    label = _(u"WindowZ Settings")
    description = _(u"Settings for the WindowZ iFrame contents.")
    form_name = _("WindowZ Settings")



# -*- coding: utf-8 -*-
#
# File: interfaces.py
#
# Copyright (c) 2007 by Jean Rodrigo Ferri
# Generator: ArchGenXML
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Jean Rodrigo Ferri <jeanrodrigoferri@yahoo.com.br>"""
__docformat__ = 'plaintext'

import zope.interface
from zope.schema import TextLine, Bool

from Products.windowZ import WindowZMessageFactory as _

class IWindow(zope.interface.Interface):
    """Window interface.
    """

    def remote_url():
        """Returns the Window URL through getFrameUrl method prefixed with
        base_url if it's selected by user.
        """
        pass

    def getPageWidth():
        """Returns page_width or the default value from portal_windowZ.
        """
        pass

    def getPageHeight():
        """Returns page_height or the default value from portal_windowZ.
        """
        pass

    def getProxies():
        """Returns the proxy configuration if it's provided by
        portal_windowZ tool.
        """
        pass

class IWindowZTool(zope.interface.Interface):
    """ Marker for windowZ tool """

class IWindowZControlPanelForm(zope.interface.Interface):
    """WindowZ Control Panel Form"""

class IWindowZSettings(zope.interface.Interface):
    """ Default settings for windowZ content objects """

    page_width = TextLine(
        title=_("windowZ_tool_label_page_width",
                default="Default Page Width"),
        description=_("windowZ_tool_help_page_width", default=(
                "Width of the iFrame area. This is the default value for the "
                "Window content types and may be redefined individually for "
                "each Window content. You may use %, px, em, etc.")),
        required=True,
        default=u"100%"
        )

    page_height = TextLine(
        title=_("windowZ_tool_label_page_height",
                default="Default Page Height"),
        description=_("windowZ_tool_help_page_height", default=(
                "Height of the iFrame area. This is the default value for the "
                "Window content types and may be redefined individually for "
                "each Window content. You may use %, px, em, etc.")),
        required=False
        )


    base_url = TextLine(
        title=_('windowZ_label_base_url', default="Base URL"),
        description=_('windowZ_help_base_url', default=(
                "Base URL provided as prefix for Window relative URLs. It's "
                "used only if the option Use Base URL? is checked.")),
        required=False,
        default=u"http://",
        )


    http_proxy = TextLine(
        title=_('windowZ_label_http_proxy', default="HTTP Proxy"),
        description=_('windowZ_help_http_proxy', default=(
                "If there is a proxy in front of the server you should enter "
                "the HTTP proxy address. It may seems like "
                "http://proxy_address:port or "
                "http://username:password@proxy_address:port.")),
        required=False,
        )

    dynamic_window = Bool(
        title=_('windowZ_label_dynamic_window',
                default="Enable Dynamic Window"),
        description=_('windowZ_help_dynamic_window', default=(
                "Check this option if you want to use show_window template "
                "to show sites provided via URL inside a window.")),
        )



# -*- coding: utf-8 -*-
# $Id$
import os
from setuptools import setup, find_packages

def _textOfModuleFile(filename):
    return open(filename, 'r').read().strip()

version = _textOfModuleFile(os.path.join('Products', 'windowZ', 'version.txt'))
long_description = _textOfModuleFile(os.path.join('Products', 'windowZ', 
                                                  'README.txt')) 
long_description += '\n\n'
long_description += _textOfModuleFile(os.path.join('docs', 'INSTALL.txt'))
long_description += '\n\n'
long_description += _textOfModuleFile(os.path.join('docs', 'HISTORY.txt'))
long_description += '\n\n'
long_description += _textOfModuleFile(os.path.join('docs', 'AUTHORS.txt'))
long_description += '\n\n'
long_description += _textOfModuleFile(os.path.join('docs', 'LICENSE.txt'))
long_description += '\n\n'

setup(name='Products.windowZ',
      version=version,
      description=("windowZ provides a new content type, named Window, "
                   "that is similar to the content type Link, but it shows "
                   "the provided relative or absolute URL inside an iFrame "
                   "rendered as a Plone page."),
      long_description=long_description.decode('ascii', 'ignore'),
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Programming Language :: Python",
        "Framework :: Plone",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Development Status :: 5 - Production/Stable",
        ],
      keywords='plone layout composition themeing',
      author='Jean Rodrigo Ferri',
      author_email='jeanrodrigoferri@yahoo.com.br',
      url='http://www.plone.org/products/windowz',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['Products'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
          'stripogram',
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )



# -*- coding: utf-8 -*-
#
# File: windowZ.py
#
# Copyright (c) 2007 by Jean Rodrigo Ferri
# Generator: ArchGenXML Version 1.5.3 dev/svn
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Jean Rodrigo Ferri <jeanrodrigoferri@yahoo.com.br>"""
__docformat__ = 'plaintext'


# There are three ways to inject custom code here:
#
#   - To set global configuration variables, create a file AppConfig.py.
#       This will be imported in config.py, which in turn is imported in
#       each generated class and in this file.
#   - To perform custom initialisation after types have been registered,
#       use the protected code section at the bottom of initialize().
#   - To register a customisation policy, create a file CustomizationPolicy.py
#       with a method register(context) to register the policy.

import logging
logger = logging.getLogger('windowZ')
logger.info('Installing Product')

import os, os.path
from App.Common import package_home
from Products.CMFCore import utils as cmfutils
from Products.CMFCore import permissions as CMFCorePermissions

from Products.CMFCore import DirectoryView
from Products.CMFCore.utils import ToolInit
from Products.Archetypes.atapi import *
from Products.Archetypes import listTypes
from Products.Archetypes.utils import capitalize
from config import *

DirectoryView.registerDirectory('skins', product_globals)

##code-section custom-init-head #fill in your manual code here
from zope.i18nmessageid import MessageFactory
WindowZMessageFactory = MessageFactory('windowZ')
##/code-section custom-init-head

def initialize(context):
    ##code-section custom-init-top #fill in your manual code here
    ##/code-section custom-init-top

    # imports packages and types for registration
    import interfaces
    import content

    import WindowZTool

    # Initialize portal tools
    ToolInit( PROJECTNAME +' Tools',
                tools = (WindowZTool.WindowZTool,),
                icon='tool.gif'
                ).initialize( context )

    # Initialize portal content
    all_content_types, all_constructors, all_ftis = process_types(
        listTypes(PROJECTNAME),
        PROJECTNAME)

    cmfutils.ContentInit(
        PROJECTNAME + ' Content',
        content_types      = all_content_types,
        permission         = ADD_CONTENT_PERMISSION,
        extra_constructors = all_constructors,
        fti                = all_ftis,
        ).initialize(context)